// Tom Buck - tom.buck@phoenixhospitalradio.com
// 2014
// Ethernet Controlled WS2801 RGB Strip

// Thanks to Adafruit for their WS2801 library and demo sketch

#include <Adafruit_WS2801.h>
#include <SPI.h>
#include <Ethernet.h>

int dataPin  = 2;    // Red wire on WS2801 Strip - Software SPI
int clockPin = 3;    // Green wire on WS2801 Strip - Software SPI

Adafruit_WS2801 strip = Adafruit_WS2801(32, dataPin, clockPin);

int x, y = 0;
byte mac[] = {
  0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED
}; //physical mac address
byte ip[] = {
  192, 168, 1, 103
}; // ip in lan
byte gateway[] = {
  192, 168, 1, 254
}; // internet access via router
byte subnet[] = {
  255, 255, 254, 0
}; //subnet mask
EthernetServer server(80); //server port
String readString; //string for fetching data from address

void setup() {
  //start Ethernet
  Ethernet.begin(mac, ip, gateway, subnet);
  //initiate the strip
  strip.begin();
  strip.show();
}

void loop() {
  // Create a client connection
  EthernetClient client = server.available();
  if (client) {
    while (client.connected()) {
      if (client.available()) {
        char c = client.read();
        //read char by char HTTP request
        if (readString.length() < 30) {
          //store characters to string
          readString.concat(c);
        }

        //if HTTP request has ended
        if (c == '\n') {
          // now output HTML data starting with standard header
          client.println("HTTP/1.1 200 OK");
          client.println("Content-Type: text/html");
          client.println();
          client.println("<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">");
          client.println("<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">");
          client.println("<head>");
          client.println("<meta http-equiv=\"content-type\" content=\"text/html; charset=iso-8859-1\" />");
          client.println("<title>Donate-O-Meter</title>");
          client.println("</head>");
          client.print("<body>");

          String amount;
          // read the posted variable
          if (readString.indexOf("amount=") > 0) {
            char amount_start = readString.indexOf("amount=") + 7; // get rid of the variable name and =
            char amount_end = readString.indexOf("HTTP/1.1"); // until you get to HTTP/1.1
            amount = readString.substring(amount_start, amount_end); // extract the variable

            // print html
            client.println();
            client.println("<font style=\"color: #339966\">Sending reply...");
            client.println("<br /><br />");
            client.print("Balance: ");
            client.println(amount); // amount value
            client.println("<br />");
            client.println("</font>");
            client.println("</body>");
            client.println("</html>"); // finish the webpage


            char this_char[amount.length() + 1]; // convert a char into int
            amount.toCharArray(this_char, sizeof(this_char));
            int x = atoi(this_char);



            if (x == 0) { // blank the strip if out of bounds entry received
              for (int l = 0; l <= strip.numPixels(); l++) {
                strip.setPixelColor(l, 0);
                strip.show();
              }
            }
            else {
              colorWipe(Color(44, 0, 44), 150); // Money Drop animation
              showmoney(x); // Send it out to the rgb strip
            }
          }



          //clearing string for next read
          readString = "";
          //stopping client
          client.stop();
        }
      }
    }
  }
}

void colorWipe(uint32_t c, uint8_t wait) { // money drop animation - purple led with 2 trails falling from top to bottom - Modified from Adafruit Strand Test
  int i;

  for (i = strip.numPixels(); i >= 0; i--) {
    strip.setPixelColor(i, c);
    strip.setPixelColor(i + 1, Color(10, 0, 10));
    strip.setPixelColor(i + 2, Color(1, 0, 1));
    strip.show();
    delay(wait);
    strip.setPixelColor(i, 0);
    strip.setPixelColor(i + 1, 0);
    strip.setPixelColor(i + 2, 0);
    strip.show();

  }

}

void showmoney(int y) { // display amount on rgb strip - Red LED's from bottom upwards

  for (int l = 0; l <= y; l++) {
    strip.setPixelColor(l, Color(128, 0, 0));
    strip.show();
  }
}


uint32_t Color(byte r, byte g, byte b) // function for making color value - Borrowed from Adafruit Strand Test
{
  uint32_t c;
  c = r;
  c <<= 8;
  c |= g;
  c <<= 8;
  c |= b;
  return c;
}















